[![GitHub Actions Workflow Status](https://img.shields.io/github/actions/workflow/status/AllenInstitute/pigeon/test.yaml)](https://github.com/AllenInstitute/pigeon/actions)
[![Documentation Status](https://readthedocs.org/projects/pigeon/badge/?version=latest)](https://pigeon.readthedocs.io/en/latest/?badge=latest)
[![PyPI - Version](https://img.shields.io/pypi/v/pigeon-client)](https://pypi.org/project/pigeon-client/)

# Pigeon

Pigeon is a combination of a [STOMP client](https://pypi.org/project/stomp-py/), and a message definition system using [Pydantic](https://docs.pydantic.dev/latest/) models.